@@ -17,7 +17,7 @@
 
 """GTK+ user interface for the Gaupol subtitle editor."""
 
-__version__ = "1.4.1"
+__version__ = "1.5"
 COMBO_SEPARATOR = "<separator/>"
 
 import sys
@@ -55,7 +55,7 @@ from gaupol import util
 from gaupol.enums import *
 from gaupol.errors import *
 from gaupol.attrdict import *
-from gaupol.config import *
+from gaupol.config import ConfigurationStore
 conf = ConfigurationStore()
 from gaupol import style
 from gaupol import ruler
@@ -96,7 +96,7 @@ from gaupol.extension import *
 from gaupol.extensionman import *
 from gaupol import agents
 from gaupol.application import *
-from gaupol.applicationman import *
+from gaupol.applicationman import ApplicationManager
 from gaupol.unittest import *
 
 def main(args):
@@ -107,5 +107,6 @@ def main(args):
     # https://wiki.gnome.org/Projects/GnomeShell/ApplicationBased
     # https://github.com/otsaloma/gaupol/issues/62
     GLib.set_prgname("gaupol")
+    aeidon.i18n.bind()
     appman = ApplicationManager(args)
     raise SystemExit(appman.run())
