@@ -104,6 +104,7 @@ class InsertSubtitleAtVideoPositionAction(gaupol.Action):
     def _affirm_doable(self, application, page, selected_rows):
         aeidon.util.affirm(page is not None)
         aeidon.util.affirm(application.player is not None)
+        aeidon.util.affirm(application.player.ready)
 
 class InsertSubtitlesAction(gaupol.Action):
     def __init__(self):
@@ -118,7 +119,7 @@ class InsertSubtitlesAction(gaupol.Action):
 class InvertSelectionAction(gaupol.Action):
     def __init__(self):
         gaupol.Action.__init__(self, "invert-selection")
-        self.accelerators = ["<Control>I"]
+        self.accelerators = ["<Control>J"]
         self.action_group = "unsafe"
     def _affirm_doable(self, application, page, selected_rows):
         aeidon.util.affirm(page is not None)
@@ -132,7 +133,7 @@ class MergeSubtitlesAction(gaupol.Action):
     def _affirm_doable(self, application, page, selected_rows):
         aeidon.util.affirm(page is not None)
         aeidon.util.affirm(len(selected_rows) > 1)
-        block = list(range(selected_rows[0], selected_rows[-1]+1))
+        block = list(range(selected_rows[0], selected_rows[-1] + 1))
         aeidon.util.affirm(list(selected_rows) == block)
 
 class RedoActionAction(gaupol.Action):
@@ -170,6 +171,7 @@ class SetEndFromVideoPositionAction(gaupol.Action):
     def _affirm_doable(self, application, page, selected_rows):
         aeidon.util.affirm(page is not None)
         aeidon.util.affirm(application.player is not None)
+        aeidon.util.affirm(application.player.ready)
         aeidon.util.affirm(len(selected_rows) == 1)
 
 class SplitSubtitleAction(gaupol.Action):
